@@ -48,7 +48,7 @@ for project in Project.NAME.value:
         elif isinstance(project_config, dict):  # OIDC
             project_authentication = ProjectInfo(
                 project=project,
-                cluster=project_config["cluster"],
+                base_url=project_config["base_url"],
                 tenant_id=project_config["tenant_id"],
                 client_id=project_config["client_id"],
                 secret_name=project_config["secret_name"],
