@@ -57,7 +57,7 @@ def handle_delete_functions():
         all_functions = [functions.get_function_name(f, latest=True) for f in function_paths] + [
             functions.get_function_name(f, pr=True, ref=ref) for ref, f in list(product(pr_refs, function_paths))
         ]
-        info = const.PROJECTS_TO_API_KEYS[project]
+        info = const.AUTHENTICATION[project]
         client = cdf.experimental_client(info.project)
         dangling = functions.list_dangling_function(client, all_functions, name_prefix=env.get_repo_name_auto())
         for function in dangling:
@@ -66,7 +66,7 @@ def handle_delete_functions():
 
 def handle_deploy_infrastructure_schedules():
     function_name, project = sys.argv[2].split("@")
-    info = const.PROJECTS_TO_API_KEYS[project]
+    info = const.AUTHENTICATION[project]
     client = cdf.experimental_client(info.project)
     execute(client)
 
