@@ -9,6 +9,7 @@ from cognite.experimental.data_classes import Function
 from requests.exceptions import ConnectionError
 from urllib3.exceptions import MaxRetryError, ReadTimeoutError
 
+import cognite.airworkflow.constants as constants
 from cognite.airworkflow.util import cdf, env
 
 CHANNEL = "model_deployment_fails"
@@ -121,15 +122,15 @@ def get_function_name(
 ) -> str:
     if isinstance(path, str):
         path = Path(path)
-    if os.getenv("CI_PROJECT_NAME"):
-        function_name = f"{os.environ['CI_PROJECT_NAME']}/{path.name}:"
+    if os.getenv(constants.gitlab_ci_project):
+        function_name = f"{os.environ[constants.gitlab_ci_project]}/{path.name}:"
     else:
         function_name = f"{env.get_repo_name_auto()}/{path.name}:"
     if latest:
         return f"{function_name}latest"
     elif pr:
-        if os.getenv("CI_MERGE_REQUEST_SOURCE_BRANCH_NAME"):
-            return f"{function_name}{ref if ref else env.get_env_value('CI_MERGE_REQUEST_SOURCE_BRANCH_NAME')}"
+        if os.getenv(constants.gitlab_function_name_addition):
+            return f"{function_name}{ref if ref else env.get_env_value(constants.gitlab_function_name_addition)}"
 
         else:
             return f"{function_name}{ref if ref else env.get_env_value('GITHUB_HEAD_REF')}"
