@@ -7,6 +7,11 @@ from ruamel.yaml import YAML
 import cognite.airworkflow.util.convert_string_times as window_size
 import cognite.airworkflow.util.cron as cron
 from cognite.airworkflow.model.config import Config
+from cognite.airworkflow.util import env
+
+working_path = env.get_env_value("PWD")
+ROOT_DIR = Path(working_path)
+REPOCONFIG_PATH = ROOT_DIR / Path("repoconfig.yaml")
 
 
 def write_yaml(path: Path, content: Dict, *, create_dirs: bool = False) -> None:
@@ -27,7 +32,7 @@ def get_validator(schema_path: Path) -> Validator:
     return validator
 
 
-def load_and_validate(path: Path, schema_path: Path) -> Config:
+def load_and_validate_config(path: Path, schema_path: Path) -> Dict:
     yaml = load_yaml(path)
     validator = get_validator(schema_path)
     is_valid = validator.validate(yaml)
@@ -37,9 +42,14 @@ def load_and_validate(path: Path, schema_path: Path) -> Config:
     if "schedule" in yaml:
         cron.validate_and_update_cron(yaml, path)
         window_size.window_size_update(yaml)
+    return yaml
 
-    return Config(yaml)
+
+def load_and_validate(path: Path, schema_path: Path, function_name: str) -> Config:
+    yaml = load_and_validate_config(path, schema_path)
+    repoconfig = load_yaml(REPOCONFIG_PATH)
+    return Config(yaml, function_name, repoconfig)
 
 
 def load_and_validate_multiple(paths: List[Path], schema_path: Path) -> Dict[Path, Config]:
-    return {p.parent.parent: load_and_validate(p, schema_path) for p in paths}
+    return {p.parent.parent: load_and_validate(p, schema_path, p.parent.parent.parts[-1]) for p in paths}
